Questions and answers
=====================

A place to record random thoughts about the daskification of
`cf.Data`, possibly prior to starting an issue on GitHub.

----

Q. When we run something that executes all of the lazy operations
   (like `cf.Data.is_masked`), should/could we replace the dask array
   with a "persisted" version of the computed data? If we did this, we
   would want to have the ability to cache persisted chunks to disk,
   as they came into being on each thread (see, for instance,
   `chest`). To do this or not do this could be controlled by a
   configuation setting.

A. ?

----

Q.

A. ?

----
